#!/bin/python3 -i

from gonchaya import *
data = pd.read_csv('/home/padla/data_science/yandex_lections/08/proj/games.csv')
#pd.DataFrame.preprocessing__normalization_of_column_names2 = MethodType(gonchaya.src_functions._preprocessing__normalization_of_column_names, data)
#data.preprocessing__normalization_of_column_names(data, report='con')
